# Contributor CI

![https://raw.githubusercontent.com/vsoch/contributor-ci/main/docs/assets/img/contributor-ci.png](https://raw.githubusercontent.com/vsoch/contributor-ci/main/docs/assets/img/contributor-ci.png)

[![GitHub Marketplace](https://img.shields.io/static/v1?label=Marketplace&message=contributor-action&color=blue?style=flat&logo=github)](https://github.com/marketplace/actions/contributor-ci-action)
[![License](https://img.shields.io/badge/license-MIT-brightgreen)](https://github.com/vsoch/contributor-ci-action/blob/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/contributor-ci)](https://pypi.org/project/contributor-ci/)

<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-1-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->


Contributor CI provides tools and visualizations for analyzing contributions. You
can read more about the library in the [documentation](https://contributor-ci.readthedocs.io/)
and releases are available on [pypi](https://pypi.org/project/contributor-ci).

![https://raw.githubusercontent.com/vsoch/contributor-ci/main/docs/assets/img/cci-interface.png](https://raw.githubusercontent.com/vsoch/contributor-ci/main/docs/assets/img/cci-interface.png)

## Thanks

The graphQL queries come from [llnl.github.io](https://github.com/LLNL/llnl.github.io) which is released
under an [MIT license](.github/LICENSE-LLNL).

## 😁️ Contributors 😁️

We use the [all-contributors](https://github.com/all-contributors/all-contributors)
tool to generate a contributors graphic below.

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://vsoch.github.io"><img src="https://avatars.githubusercontent.com/u/814322?v=4?s=100" width="100px;" alt="Vanessasaurus"/><br /><sub><b>Vanessasaurus</b></sub></a><br /><a href="https://github.com/converged-computing/cloud-select/commits?author=vsoch" title="Code">💻</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
